@@ -1,9 +1,10 @@
-""" Main file to calculate infomation of a pytorch model. """
+""" Main file to calculate information of a pytorch model. """
 import numpy as np
 from tabulate import tabulate
 import torch
 
 from flopth.helper import compute_flops
+from flopth.utils import divide_by_unit
 
 
 class ModelViewer:
@@ -61,7 +62,7 @@ class ModelViewer:
 
     def apply_forward_hook(self):
         def forward_with_hook(module, *args, **kwargs):
-            # Calulate FLOPs of current module
+            # Calculate FLOPs of current module
             output = self.forward_funcs[module.__class__](module, *args, **kwargs)
             args_list = list(args)
             module.flops = torch.from_numpy(
@@ -75,17 +76,6 @@ class ModelViewer:
                 self.forward_funcs[m.__class__] = m.__class__.__call__
                 m.__class__.__call__ = forward_with_hook
 
-    def divide_by_unit(self, value):
-        if isinstance(value, np.ndarray):
-            value = float(value)
-        if value > 1e9:
-            return "{:.6}G".format(value / 1e9)
-        elif value > 1e6:
-            return "{:.6}M".format(value / 1e6)
-        elif value > 1e3:
-            return "{:.6}K".format(value / 1e3)
-        return "{:.6}".format(value / 1.0)
-
     def show_info(self, show_detail=True):
         sum_flops = torch.zeros((1), dtype=torch.int64)
         if torch.cuda.is_available():
@@ -100,14 +90,16 @@ class ModelViewer:
             else:
                 sum_flops += m.flops[0].item()
         sum_flops = (
-            sum_flops.detach().cpu().numpy()
+            sum_flops.detach().cpu().numpy().item()
             if sum_flops.is_cuda
-            else sum_flops.detach().numpy()
+            else sum_flops.detach().numpy().item()
         )
+        sum_params = sum(np.prod(v.size()) for v in self._model.parameters())
+
         if show_detail:
             info = []
             for m, n in zip(self.leaf_modules, self.leaf_module_names):
-                param = str(sum(np.prod(v.size()) for v in m.parameters()))
+                param = sum(np.prod(v.size()) for v in m.parameters())
                 m_type = (
                     str(type(m))
                     .split(">")[0]
@@ -141,12 +133,16 @@ class ModelViewer:
                         m_type,
                         in_shape_str,
                         out_shape_str,
-                        param,
-                        self.divide_by_unit(flops),
-                        "{:.6}%".format(float(flops) / float(sum_flops) * 100)
+                        divide_by_unit(param),
+                        "{:.6}%".format(param / sum_params * 100)
+                        if sum_params > 0
+                        else "",
+                        "#" * int(param / sum_params * 50) if sum_params > 0 else "",
+                        divide_by_unit(flops),
+                        "{:.6}%".format(flops / sum_flops * 100)
                         if sum_flops > 0
                         else "",
-                        "#" * int(float(flops) / float(sum_flops) * 100) if sum_flops > 0 else "",
+                        "#" * int(flops / sum_flops * 50) if sum_flops > 0 else "",
                     ]
                 )
             print(
@@ -158,6 +154,8 @@ class ModelViewer:
                         "in_shape",
                         "out_shape",
                         "params",
+                        "params_percent",
+                        "params_percent_vis",
                         "flops",
                         "flops_percent",
                         "flops_percent_vis",
@@ -170,10 +168,11 @@ class ModelViewer:
             # sum_flops_str = self.divide_by_unit(sum_flops)
             # print('\nTotal FLOPs: {}'.format(sum_flops_str))
 
-        return sum_flops
+        return sum_flops, sum_params
 
     def get_info(self, for_human=True):
-        flops = self.show_info(show_detail=False)
+        flops, params = self.show_info(show_detail=False)
         if for_human:
-            flops = self.divide_by_unit(flops)
-        return flops
+            flops = divide_by_unit(flops)
+            params = divide_by_unit(params)
+        return flops, params
